==> infinitic-storage-0.6.4-sources.jar: io/infinitic/storage/redis/getPool.kt <==
/**
 * "Commons Clause" License Condition v1.0
 *
 * The Software is provided to you by the Licensor under the License, as defined
 * below, subject to the following condition.
 *
 * Without limiting other conditions in the License, the grant of rights under the
 * License will not include, and the License does not grant to you, the right to
 * Sell the Software.
 *
 * For purposes of the foregoing, “Sell” means practicing any or all of the rights
 * granted to you under the License to provide to third parties, for a fee or
 * other consideration (including without limitation fees for hosting or
 * consulting/ support services related to the Software), a product or service
 * whose value derives, entirely or substantially, from the functionality of the
 * Software. Any license notice or attribution required by the License must also
 * include this Commons Clause License Condition notice.
 *
 * Software: Infinitic
 *
 * License: MIT License (https://opensource.org/licenses/MIT)
 *
 * Licensor: infinitic.io
 */

package io.infinitic.storage.redis

import redis.clients.jedis.JedisPool
import redis.clients.jedis.JedisPoolConfig

fun getPool(
    host: String,
    port: Int,
    timeout: Int,
    user: String?,
    password: String?,
    database: Int,
    ssl: Boolean,
    jedisPoolConfig: JedisPoolConfig = JedisPoolConfig()
) = when (password.isNullOrEmpty()) {
    true -> JedisPool(jedisPoolConfig, host, port, database)
    false -> JedisPool(jedisPoolConfig, host, port, timeout, user, password, database, ssl)
}

fun getPool(config: Redis) = getPool(
    host = config.host,
    port = config.port,
    timeout = config.timeout,
    user = config.user,
    password = config.password,
    database = config.database,
    ssl = config.ssl
)

==> infinitic-storage-0.7.3-sources.jar: io/infinitic/storage/redis/getPool.kt <==
/**
 * "Commons Clause" License Condition v1.0
 *
 * The Software is provided to you by the Licensor under the License, as defined
 * below, subject to the following condition.
 *
 * Without limiting other conditions in the License, the grant of rights under the
 * License will not include, and the License does not grant to you, the right to
 * Sell the Software.
 *
 * For purposes of the foregoing, “Sell” means practicing any or all of the rights
 * granted to you under the License to provide to third parties, for a fee or
 * other consideration (including without limitation fees for hosting or
 * consulting/ support services related to the Software), a product or service
 * whose value derives, entirely or substantially, from the functionality of the
 * Software. Any license notice or attribution required by the License must also
 * include this Commons Clause License Condition notice.
 *
 * Software: Infinitic
 *
 * License: MIT License (https://opensource.org/licenses/MIT)
 *
 * Licensor: infinitic.io
 */

package io.infinitic.storage.redis

import redis.clients.jedis.JedisPool
import redis.clients.jedis.JedisPoolConfig

fun getPool(
    host: String,
    port: Int,
    timeout: Int,
    user: String?,
    password: String?,
    database: Int,
    ssl: Boolean,
    jedisPoolConfig: JedisPoolConfig = JedisPoolConfig()
) = when (password.isNullOrEmpty()) {
    true -> JedisPool(jedisPoolConfig, host, port, database)
    false -> JedisPool(jedisPoolConfig, host, port, timeout, user, password, database, ssl)
}

fun getPool(config: Redis) = getPool(
    host = config.host,
    port = config.port,
    timeout = config.timeout,
    user = config.user,
    password = config.password?.value,
    database = config.database,
    ssl = config.ssl
)
